@@ -14,26 +14,26 @@
 """
 XML interface specifications.
 """
+# isort: STDLIB
+import sys
+import xml.etree.ElementTree as ET
 from os import environ
 
-import sys
-
-import xml.etree.ElementTree as ET
-
-from dbus_client_gen import managed_object_class
-from dbus_client_gen import mo_query_builder
-from dbus_client_gen import DbusClientGenerationError
-
-from dbus_python_client_gen import make_class
-from dbus_python_client_gen import DPClientGenerationError
-
-from .._errors import StratisCliEnvironmentError
-from .._errors import StratisCliGenerationError
-
-from ._constants import BLOCKDEV_INTERFACE
-from ._constants import FILESYSTEM_INTERFACE
-from ._constants import POOL_INTERFACE
+# isort: FIRSTPARTY
+from dbus_client_gen import (
+    DbusClientGenerationError,
+    managed_object_class,
+    mo_query_builder,
+)
+from dbus_python_client_gen import DPClientGenerationError, make_class
 
+from .._errors import StratisCliEnvironmentError, StratisCliGenerationError
+from ._constants import (
+    BLOCKDEV_INTERFACE,
+    FETCH_PROPERTIES_INTERFACE,
+    FILESYSTEM_INTERFACE,
+    POOL_INTERFACE,
+)
 
 assert hasattr(sys.modules.get("stratis_cli"), "run"), (
     "This module is being loaded too eagerly. Make sure that loading it is "
@@ -49,8 +49,19 @@ SPECS = {
 </method>
 </interface>
 """,
-    "org.storage.stratis1.Manager": """
-<interface name="org.storage.stratis1.Manager">
+    "org.storage.stratis2.FetchProperties": """
+<interface name="org.storage.stratis2.FetchProperties">
+<method name="GetAllProperties">
+<arg name="property_hash" type="a{s(bv)}" direction="out"/>
+</method>
+<method name="GetProperties">
+<arg name="properties" type="as" direction="in"/>
+<arg name="property_hash" type="a{s(bv)}" direction="out"/>
+</method>
+</interface>
+""",
+    "org.storage.stratis2.Manager": """
+<interface name="org.storage.stratis2.Manager">
 <method name="ConfigureSimulator">
 <arg name="denominator" type="u" direction="in"/>
 <arg name="return_code" type="q" direction="out"/>
@@ -60,13 +71,13 @@ SPECS = {
 <arg name="name" type="s" direction="in"/>
 <arg name="redundancy" type="(bq)" direction="in"/>
 <arg name="devices" type="as" direction="in"/>
-<arg name="result" type="(oao)" direction="out"/>
+<arg name="result" type="(b(oao))" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
 <method name="DestroyPool">
 <arg name="pool" type="o" direction="in"/>
-<arg name="action" type="b" direction="out"/>
+<arg name="result" type="(bs)" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
@@ -75,73 +86,58 @@ SPECS = {
 </property>
 </interface>
 """,
-    "org.storage.stratis1.pool": """
-<interface name="org.storage.stratis1.pool">
+    "org.storage.stratis2.pool": """
+<interface name="org.storage.stratis2.pool">
 <method name="AddCacheDevs">
 <arg name="devices" type="as" direction="in"/>
-<arg name="results" type="ao" direction="out"/>
+<arg name="results" type="(bao)" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
 <method name="AddDataDevs">
 <arg name="devices" type="as" direction="in"/>
-<arg name="results" type="ao" direction="out"/>
+<arg name="results" type="(bao)" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
 <method name="CreateFilesystems">
 <arg name="specs" type="as" direction="in"/>
-<arg name="filesystems" type="a(os)" direction="out"/>
+<arg name="results" type="(ba(os))" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
 <method name="DestroyFilesystems">
 <arg name="filesystems" type="ao" direction="in"/>
-<arg name="results" type="as" direction="out"/>
+<arg name="results" type="(bas)" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
 <method name="SetName">
 <arg name="name" type="s" direction="in"/>
-<arg name="action" type="b" direction="out"/>
+<arg name="result" type="(bs)" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
 <method name="SnapshotFilesystem">
 <arg name="origin" type="o" direction="in"/>
 <arg name="snapshot_name" type="s" direction="in"/>
-<arg name="result" type="o" direction="out"/>
+<arg name="result" type="(bo)" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
 <property name="Name" type="s" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="true"/>
 </property>
-<property name="TotalPhysicalSize" type="s" access="read">
-<annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="false"/>
-</property>
-<property name="TotalPhysicalUsed" type="s" access="read">
-<annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="false"/>
-</property>
 <property name="Uuid" type="s" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="const"/>
 </property>
-<property name="State" type="q" access="read">
-<annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="true"/>
-</property>
-<property name="ExtendState" type="q" access="read">
-<annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="true"/>
-</property>
-<property name="SpaceState" type="q" access="read">
-<annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="true"/>
-</property>
 </interface>
 """,
-    "org.storage.stratis1.filesystem": """
-<interface name="org.storage.stratis1.filesystem">
+    "org.storage.stratis2.filesystem": """
+<interface name="org.storage.stratis2.filesystem">
 <method name="SetName">
 <arg name="name" type="s" direction="in"/>
-<arg name="action" type="b" direction="out"/>
+<arg name="action" type="(bs)" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
@@ -157,26 +153,23 @@ SPECS = {
 <property name="Pool" type="o" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="const"/>
 </property>
-<property name="Used" type="s" access="read">
-<annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="false"/>
-</property>
 <property name="Uuid" type="s" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="const"/>
 </property>
 </interface>
 """,
-    "org.storage.stratis1.blockdev": """
-<interface name="org.storage.stratis1.blockdev">
+    "org.storage.stratis2.blockdev": """
+<interface name="org.storage.stratis2.blockdev">
 <method name="SetUserInfo">
-<arg name="id" type="s" direction="in"/>
-<arg name="changed" type="b" direction="out"/>
+<arg name="id" type="(bs)" direction="in"/>
+<arg name="result" type="(bs)" direction="out"/>
 <arg name="return_code" type="q" direction="out"/>
 <arg name="return_string" type="s" direction="out"/>
 </method>
 <property name="Devnode" type="s" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="const"/>
 </property>
-<property name="HardwareInfo" type="s" access="read">
+<property name="HardwareInfo" type="(bs)" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="const"/>
 </property>
 <property name="InitializationTime" type="t" access="read">
@@ -185,16 +178,10 @@ SPECS = {
 <property name="Pool" type="o" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="const"/>
 </property>
-<property name="State" type="q" access="read">
-<annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="true"/>
-</property>
 <property name="Tier" type="q" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="false"/>
 </property>
-<property name="TotalPhysicalSize" type="s" access="read">
-<annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="false"/>
-</property>
-<property name="UserInfo" type="s" access="read">
+<property name="UserInfo" type="(bs)" access="read">
 <annotation name="org.freedesktop.DBus.Property.EmitsChangedSignal" value="false"/>
 </property>
 <property name="Uuid" type="s" access="read">
@@ -204,7 +191,7 @@ SPECS = {
 """,
 }
 
-_MANAGER_INTERFACE = "org.storage.stratis1.Manager"
+_MANAGER_INTERFACE = "org.storage.stratis2.Manager"
 
 DBUS_TIMEOUT_SECONDS = 120
 MAXIMUM_DBUS_TIMEOUT_MS = 1073741823
@@ -256,6 +243,9 @@ try:
         environ.get("STRATIS_DBUS_TIMEOUT", DBUS_TIMEOUT_SECONDS * 1000)
     )
 
+    fetch_properties_spec = ET.fromstring(SPECS[FETCH_PROPERTIES_INTERFACE])
+    FetchProperties = make_class("FetchProperties", fetch_properties_spec, timeout)
+
     filesystem_spec = ET.fromstring(SPECS[FILESYSTEM_INTERFACE])
     Filesystem = make_class("Filesystem", filesystem_spec, timeout)
     MOFilesystem = managed_object_class("MOFilesystem", filesystem_spec)
